error property
What the last attempt of the failed fetch threw. A cancelled fetch that
was not reverted fails with a CancelledError.
Implementation
final Object error;
What the last attempt of the failed fetch threw. A cancelled fetch that
was not reverted fails with a CancelledError.
final Object error;