RefetchOnAlways class final Option values

The RefetchOn.always variant: the event refetches, fresh data or not.

Inheritance

Constructors

RefetchOnAlways()
The one instance is RefetchOn.always; a const RefetchOnAlways() is the same value.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Query<Object?> query) → RefetchOn
This with any RefetchOn.when layer peeled off for query, so the result is never, ifStale or always.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override