count property
How many failures are tolerated before the fetch is an error. 0
behaves like RetryPolicy.never — the two are distinct values of a
sealed type, so they are not ==.
Implementation
final int count;
How many failures are tolerated before the fetch is an error. 0
behaves like RetryPolicy.never — the two are distinct values of a
sealed type, so they are not ==.
final int count;